==> Statemate4.6.1.7Documentation.tar.gz: STM_HELP/help_doc/MultiVolume/Output/Using Statemate/wwhdata/js/search/pairs/pair177.js <==
function FileData_Pairs(x)
{
x.t("states","modes");
x.t("states","decomposed");
x.t("modes","change");
x.t("modes","system");
x.t("example","event");
x.t("supports","special");
x.t("properties","contain");
x.t("procedural","statechart");
x.t("editors","working");
x.t("extensive","generalization");
x.t("within","single");
x.t("timing","information");
x.t("timing","behavior");
x.t("events","cause");
x.t("events","conditions");
x.t("mechanism","timeout");
x.t("synchronization","timing");
x.t("synchronization","statecharts");
x.t("questions","causality");
x.t("causality","concurrency");
x.t("creates","graphical");
x.t("diagrams","allow");
x.t("diagrams","statecharts");
x.t("dynamics","activities");
x.t("working","charts");
x.t("support","economical");
x.t("change","occurrences");
x.t("encapsulation","incorporate");
x.t("type","statechart");
x.t("time","including");
x.t("derivative","statechart");
x.t("sections","describe");
x.t("default","termination");
x.t("element","statechart");
x.t("element","used");
x.t("single","step");
x.t("fashion","thus");
x.t("state-transition","diagrams");
x.t("rational","statemate");
x.t("decomposed","and/or");
x.t("graphical","notion");
x.t("generalization","state-transition");
x.t("communication","mechanism");
x.t("transitions","depend");
x.t("provides","answers");
x.t("place","thus");
x.t("compound","event");
x.t("allow","multi-level");
x.t("contain","additional");
x.t("contain","termination");
x.t("charts","diagrams");
x.t("delay","operators");
x.t("operators","specifying");
x.t("statechart","properties");
x.t("statechart","procedural");
x.t("statechart","known");
x.t("statechart","specialized");
x.t("statechart","following");
x.t("means","specifying");
x.t("depend","history");
x.t("control","timing");
x.t("cause","modes");
x.t("number","assigning");
x.t("notion","transition");
x.t("define","compound");
x.t("step","contain");
x.t("step","following");
x.t("system's","behavior");
x.t("transition","creates");
x.t("transition","priority");
x.t("executed","entirely");
x.t("connector","called");
x.t("connector","including");
x.t("thus","support");
x.t("thus","provides");
x.t("multi-level","states");
x.t("known","procedural");
x.t("incorporate","broadcast");
x.t("event","element");
x.t("event","expression");
x.t("concurrency","synchronization");
x.t("concurrency","encapsulation");
x.t("and/or","fashion");
x.t("value","positive");
x.t("additional","information");
x.t("statecharts","statecharts");
x.t("statecharts","constitute");
x.t("statecharts","using");
x.t("statecharts","describe");
x.t("termination","connector");
x.t("broadcast","communication");
x.t("expression","involving");
x.t("runs","default");
x.t("specifying","synchronization");
x.t("specifying","transitions");
x.t("graphic","editors");
x.t("information","example");
x.t("information","means");
x.t("timeout","delay");
x.t("statemate","supports");
x.t("activities","control");
x.t("specification","concurrency");
x.t("specialized","derivative");
x.t("called","runs");
x.t("constitute","extensive");
x.t("economical","specification");
x.t("history","system's");
x.t("priority","element");
x.t("priority","value");
x.t("priority","adding");
x.t("integer","number");
x.t("note","rational");
x.t("answers","questions");
x.t("positive","integer");
x.t("occurrences","place");
x.t("involving","events");
x.t("entirely","step");
x.t("system","conditions");
x.t("used","define");
x.t("special","type");
x.t("following","sections");
x.t("following","executed");
x.t("loops","within");
x.t("using","graphic");
x.t("adding","priority");
x.t("assigning","transition");
x.t("behavior","states");
x.t("behavior","time");
x.t("behavior","transition");
x.t("describe","system's");
x.t("describe","detail");
x.t("including","dynamics");
x.t("including","loops");
x.t("conditions","events");
x.t("conditions","note");
x.t("detail","statecharts");
}

==> Statemate4.6.1.10Documentation.tar.gz: STM_HELP/help_doc/MultiVolume/Output/Using Statemate/wwhdata/js/search/pairs/pair177.js <==
function FileData_Pairs(x)
{
x.t("states","modes");
x.t("states","decomposed");
x.t("modes","change");
x.t("modes","system");
x.t("example","event");
x.t("supports","special");
x.t("subroutine","procedural");
x.t("properties","contain");
x.t("procedural","statechart");
x.t("editors","working");
x.t("extensive","generalization");
x.t("within","single");
x.t("timing","information");
x.t("timing","behavior");
x.t("events","cause");
x.t("events","conditions");
x.t("mechanism","timeout");
x.t("synchronization","timing");
x.t("synchronization","statecharts");
x.t("questions","causality");
x.t("causality","concurrency");
x.t("creates","graphical");
x.t("diagrams","allow");
x.t("diagrams","statecharts");
x.t("dynamics","activities");
x.t("working","charts");
x.t("support","economical");
x.t("change","occurrences");
x.t("encapsulation","incorporate");
x.t("type","statechart");
x.t("time","including");
x.t("derivative","statechart");
x.t("sections","describe");
x.t("default","termination");
x.t("element","statechart");
x.t("element","used");
x.t("single","step");
x.t("fashion","thus");
x.t("state-transition","diagrams");
x.t("rational","statemate");
x.t("decomposed","and/or");
x.t("graphical","notion");
x.t("generalization","state-transition");
x.t("communication","mechanism");
x.t("transitions","depend");
x.t("provides","answers");
x.t("place","thus");
x.t("compound","event");
x.t("allow","multi-level");
x.t("contain","additional");
x.t("contain","termination");
x.t("charts","diagrams");
x.t("delay","operators");
x.t("operators","specifying");
x.t("statechart","properties");
x.t("statechart","known");
x.t("statechart","specialized");
x.t("statechart","used");
x.t("statechart","following");
x.t("means","specifying");
x.t("depend","history");
x.t("control","timing");
x.t("cause","modes");
x.t("number","assigning");
x.t("notion","transition");
x.t("define","compound");
x.t("step","contain");
x.t("step","following");
x.t("system's","behavior");
x.t("transition","creates");
x.t("transition","priority");
x.t("executed","entirely");
x.t("connector","called");
x.t("connector","including");
x.t("thus","support");
x.t("thus","provides");
x.t("multi-level","states");
x.t("known","procedural");
x.t("incorporate","broadcast");
x.t("event","element");
x.t("event","expression");
x.t("concurrency","synchronization");
x.t("concurrency","encapsulation");
x.t("and/or","fashion");
x.t("value","positive");
x.t("additional","information");
x.t("statecharts","statecharts");
x.t("statecharts","constitute");
x.t("statecharts","using");
x.t("statecharts","describe");
x.t("implementation","subroutine");
x.t("termination","connector");
x.t("broadcast","communication");
x.t("expression","involving");
x.t("runs","default");
x.t("specifying","synchronization");
x.t("specifying","transitions");
x.t("graphic","editors");
x.t("information","example");
x.t("information","means");
x.t("timeout","delay");
x.t("statemate","supports");
x.t("activities","control");
x.t("specification","concurrency");
x.t("specialized","derivative");
x.t("called","runs");
x.t("constitute","extensive");
x.t("economical","specification");
x.t("history","system's");
x.t("priority","element");
x.t("priority","value");
x.t("priority","adding");
x.t("integer","number");
x.t("note","rational");
x.t("answers","questions");
x.t("positive","integer");
x.t("occurrences","place");
x.t("involving","events");
x.t("entirely","step");
x.t("system","conditions");
x.t("used","define");
x.t("used","implementation");
x.t("special","type");
x.t("following","sections");
x.t("following","executed");
x.t("loops","within");
x.t("using","graphic");
x.t("adding","priority");
x.t("assigning","transition");
x.t("behavior","states");
x.t("behavior","time");
x.t("behavior","transition");
x.t("describe","system's");
x.t("describe","detail");
x.t("including","dynamics");
x.t("including","loops");
x.t("conditions","events");
x.t("conditions","note");
x.t("detail","statecharts");
}
